@@ -723,11 +723,13 @@ on_2x2_clicked (GtkMenuItem *i, GnomePrintJobPreview *mp)
 	preview_zoom_fit_cmd (NULL, mp);
 }
 
+#if 0
 static void
 on_other_clicked (GtkMenuItem *i, GnomePrintJobPreview *mp)
 {
 	g_warning ("Not implemented!");
 }
+#endif
 
 static void
 gpmp_multi_cmd (GtkWidget *w, GnomePrintJobPreview *mp)
@@ -759,11 +761,13 @@ gpmp_multi_cmd (GtkWidget *w, GnomePrintJobPreview *mp)
 	gtk_menu_attach (GTK_MENU (m), i, 1, 2, 1, 2);
         g_signal_connect (i, "activate", G_CALLBACK (on_2x2_clicked), mp);
 
+#if 0
         i = gtk_menu_item_new_with_label (_("Other"));
         gtk_widget_show (i);
 	gtk_menu_attach (GTK_MENU (m), i, 0, 2, 2, 3);
         gtk_widget_set_sensitive (i, FALSE);
         g_signal_connect (i, "activate", G_CALLBACK (on_other_clicked), mp);
+#endif
 
 	gtk_menu_popup (GTK_MENU (m), NULL, NULL, NULL, mp, 0,
 			GDK_CURRENT_TIME);
@@ -879,7 +883,7 @@ create_toplevel (GnomePrintJobPreview *mp)
 	gtk_widget_show (GTK_WIDGET (i));
 	gtk_toolbar_insert (GTK_TOOLBAR (tb), i, -1);
 
-	i = gtk_tool_button_new_from_stock (GTK_STOCK_MISSING_IMAGE);
+	i = gtk_tool_button_new_from_stock (GTK_STOCK_DND_MULTIPLE);
 	gtk_tool_item_set_tooltip (i, GTK_TOOLBAR (tb)->tooltips,
 				   _("View multiple pages"), "");
 	g_signal_connect (i, "clicked", G_CALLBACK (gpmp_multi_cmd), mp);
